@@ -9,7 +9,7 @@
 #define Q_BIG_ENDIAN 4321
 #define Q_LITTLE_ENDIAN 1234
 #define QT_BUILD_KEY "generic openbsd g++-4 full-config"
-#define QT_BUILD_KEY_COMPAT "sparc64 OpenBSD g++-4 full-config"
+#define QT_BUILD_KEY_COMPAT "hppa OpenBSD g++-4 full-config"
 
 #ifdef QT_BOOTSTRAPPED
 #define Q_BYTE_ORDER Q_BIG_ENDIAN
@@ -24,7 +24,7 @@
 #endif
 /* Compile time features */
 #define QT_LARGEFILE_SUPPORT 64
-#define QT_POINTER_SIZE 8
+#define QT_POINTER_SIZE 4
 
 #ifndef QT_BOOTSTRAPPED
 
@@ -46,24 +46,12 @@
 # define QT_NO_EGL
 #endif
 
-#if defined(QT_NO_GUI) && defined(QT_GUI)
-# undef QT_NO_GUI
-#elif !defined(QT_NO_GUI) && !defined(QT_GUI)
-# define QT_NO_GUI
-#endif
-
 #if defined(QT_NO_ICD) && defined(QT_ICD)
 # undef QT_NO_ICD
 #elif !defined(QT_NO_ICD) && !defined(QT_ICD)
 # define QT_NO_ICD
 #endif
 
-#if defined(QT_NO_ICONV) && defined(QT_ICONV)
-# undef QT_NO_ICONV
-#elif !defined(QT_NO_ICONV) && !defined(QT_ICONV)
-# define QT_NO_ICONV
-#endif
-
 #if defined(QT_NO_IMAGEFORMAT_JPEG) && defined(QT_IMAGEFORMAT_JPEG)
 # undef QT_NO_IMAGEFORMAT_JPEG
 #elif !defined(QT_NO_IMAGEFORMAT_JPEG) && !defined(QT_IMAGEFORMAT_JPEG)
