@@ -1,58 +1,59 @@
 /****************************************************************************
 **
-** Copyright (C) 1992-2008 Trolltech ASA. All rights reserved.
+** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
+** All rights reserved.
+** Contact: Nokia Corporation (qt-info@nokia.com)
 **
 ** This file is part of the QtCore module of the Qt Toolkit.
 **
-** This file may be used under the terms of the GNU General Public
-** License versions 2.0 or 3.0 as published by the Free Software
-** Foundation and appearing in the files LICENSE.GPL2 and LICENSE.GPL3
-** included in the packaging of this file.  Alternatively you may (at
-** your option) use any later version of the GNU General Public
-** License if such license has been publicly approved by Trolltech ASA
-** (or its successors, if any) and the KDE Free Qt Foundation. In
-** addition, as a special exception, Trolltech gives you certain
-** additional rights. These rights are described in the Trolltech GPL
-** Exception version 1.2, which can be found at
-** http://www.trolltech.com/products/qt/gplexception/ and in the file
-** GPL_EXCEPTION.txt in this package.
+** $QT_BEGIN_LICENSE:LGPL$
+** GNU Lesser General Public License Usage
+** This file may be used under the terms of the GNU Lesser General Public
+** License version 2.1 as published by the Free Software Foundation and
+** appearing in the file LICENSE.LGPL included in the packaging of this
+** file. Please review the following information to ensure the GNU Lesser
+** General Public License version 2.1 requirements will be met:
+** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
 **
-** Please review the following information to ensure GNU General
-** Public Licensing requirements will be met:
-** http://trolltech.com/products/qt/licenses/licensing/opensource/. If
-** you are unsure which license is appropriate for your use, please
-** review the following information:
-** http://trolltech.com/products/qt/licenses/licensing/licensingoverview
-** or contact the sales department at sales@trolltech.com.
+** In addition, as a special exception, Nokia gives you certain additional
+** rights. These rights are described in the Nokia Qt LGPL Exception
+** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
 **
-** In addition, as a special exception, Trolltech, as the sole
-** copyright holder for Qt Designer, grants users of the Qt/Eclipse
-** Integration plug-in the right for the Qt/Eclipse Integration to
-** link to functionality provided by Qt Designer and its related
-** libraries.
+** GNU General Public License Usage
+** Alternatively, this file may be used under the terms of the GNU General
+** Public License version 3.0 as published by the Free Software Foundation
+** and appearing in the file LICENSE.GPL included in the packaging of this
+** file. Please review the following information to ensure the GNU General
+** Public License version 3.0 requirements will be met:
+** http://www.gnu.org/copyleft/gpl.html.
 **
-** This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-** INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-** A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-** granted herein.
+** Other Usage
+** Alternatively, this file may be used in accordance with the terms and
+** conditions contained in a signed written agreement between you and Nokia.
 **
-** This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
-** WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
+**
+**
+**
+**
+** $QT_END_LICENSE$
 **
 ****************************************************************************/
 
 #ifndef QURL_H
 #define QURL_H
 
+#include <QtCore/qbytearray.h>
 #include <QtCore/qobjectdefs.h>
 #include <QtCore/qpair.h>
 #include <QtCore/qstring.h>
+#include <QtCore/qhash.h>
 
 QT_BEGIN_HEADER
 
+QT_BEGIN_NAMESPACE
+
 QT_MODULE(Core)
 
-class QByteArray;
 class QUrlPrivate;
 class QDataStream;
 
@@ -75,20 +76,32 @@ public:
         RemovePath = 0x20,
         RemoveQuery = 0x40,
         RemoveFragment = 0x80,
+        // 0x100: private: normalized
 
         StripTrailingSlash = 0x10000
     };
     Q_DECLARE_FLAGS(FormattingOptions, FormattingOption)
 
     QUrl();
+#ifdef QT_NO_URL_CAST_FROM_STRING
+    explicit
+#endif
     QUrl(const QString &url);
     QUrl(const QString &url, ParsingMode mode);
     // ### Qt 5: merge the two constructors, with mode = TolerantMode
     QUrl(const QUrl &copy);
     QUrl &operator =(const QUrl &copy);
+#ifndef QT_NO_URL_CAST_FROM_STRING
     QUrl &operator =(const QString &url);
+#endif
+#ifdef Q_COMPILER_RVALUE_REFS
+    inline QUrl &operator=(QUrl &&other)
+    { qSwap(d, other.d); return *this; }
+#endif
     ~QUrl();
 
+    inline void swap(QUrl &other) { qSwap(d, other.d); }
+
     void setUrl(const QString &url);
     void setUrl(const QString &url, ParsingMode mode);
     // ### Qt 5: merge the two setUrl() functions, with mode = TolerantMode
@@ -113,12 +126,18 @@ public:
 
     void setUserName(const QString &userName);
     QString userName() const;
+    void setEncodedUserName(const QByteArray &userName);
+    QByteArray encodedUserName() const;
 
     void setPassword(const QString &password);
     QString password() const;
+    void setEncodedPassword(const QByteArray &password);
+    QByteArray encodedPassword() const;
 
     void setHost(const QString &host);
     QString host() const;
+    void setEncodedHost(const QByteArray &host);
+    QByteArray encodedHost() const;
 
     void setPort(int port);
     int port() const;
@@ -127,6 +146,8 @@ public:
 
     void setPath(const QString &path);
     QString path() const;
+    void setEncodedPath(const QByteArray &path);
+    QByteArray encodedPath() const;
 
     bool hasQuery() const;
 
@@ -146,9 +167,23 @@ public:
     void removeQueryItem(const QString &key);
     void removeAllQueryItems(const QString &key);
 
+    void setEncodedQueryItems(const QList<QPair<QByteArray, QByteArray> > &query);
+    void addEncodedQueryItem(const QByteArray &key, const QByteArray &value);
+    QList<QPair<QByteArray, QByteArray> > encodedQueryItems() const;
+    bool hasEncodedQueryItem(const QByteArray &key) const;
+    QByteArray encodedQueryItemValue(const QByteArray &key) const;
+    QList<QByteArray> allEncodedQueryItemValues(const QByteArray &key) const;
+    void removeEncodedQueryItem(const QByteArray &key);
+    void removeAllEncodedQueryItems(const QByteArray &key);
+
     void setFragment(const QString &fragment);
     QString fragment() const;
+    void setEncodedFragment(const QByteArray &fragment);
+    QByteArray encodedFragment() const;
     bool hasFragment() const;
+#ifndef QT_BOOTSTRAPPED
+    QString topLevelDomain() const;
+#endif
 
     QUrl resolved(const QUrl &relative) const;
 
@@ -157,6 +192,7 @@ public:
 
     static QUrl fromLocalFile(const QString &localfile);
     QString toLocalFile() const;
+    bool isLocalFile() const;
 
     QString toString(FormattingOptions options = None) const;
 
@@ -165,6 +201,8 @@ public:
     static QUrl fromEncoded(const QByteArray &url, ParsingMode mode);
     // ### Qt 5: merge the two fromEncoded() functions, with mode = TolerantMode
 
+    static QUrl fromUserInput(const QString &userInput);
+
     void detach();
     bool isDetached() const;
 
@@ -199,12 +237,12 @@ public:
     }
     inline QT3_SUPPORT QString query() const
     {
-        return QString::fromLatin1(encodedQuery());
+        return QString::fromLatin1(encodedQuery().constData());
     }
     inline QT3_SUPPORT QString ref() const { return fragment(); }
     inline QT3_SUPPORT void setRef(const QString &txt) { setFragment(txt); }
     inline QT3_SUPPORT bool hasRef() const { return !fragment().isEmpty(); }
-    inline QT3_SUPPORT void addPath(const QString &p) { setPath(path() + QLatin1String("/") + p); }
+    inline QT3_SUPPORT void addPath(const QString &p) { setPath(path() + QLatin1Char('/') + p); }
     QT3_SUPPORT void setFileName(const QString &txt);
     QT3_SUPPORT QString fileName() const;
     QT3_SUPPORT QString dirPath() const;
@@ -214,7 +252,7 @@ public:
     }
     static inline QT3_SUPPORT void encode(QString &url)
     {
-        url = QString::fromLatin1(QUrl::toPercentEncoding(url));
+        url = QString::fromLatin1(QUrl::toPercentEncoding(url).constData());
     }
     inline QT3_SUPPORT operator QString() const { return toString(); }
     inline QT3_SUPPORT bool cdUp()
@@ -242,6 +280,11 @@ public:
     inline DataPtr &data_ptr() { return d; }
 };
 
+inline uint qHash(const QUrl &url)
+{
+    return qHash(url.toEncoded(QUrl::FormattingOption(0x100)));
+}
+
 Q_DECLARE_TYPEINFO(QUrl, Q_MOVABLE_TYPE);
 Q_DECLARE_SHARED(QUrl)
 Q_DECLARE_OPERATORS_FOR_FLAGS(QUrl::FormattingOptions)
@@ -255,6 +298,8 @@ Q_CORE_EXPORT QDataStream &operator>>(QDataStream &, QUrl &);
 Q_CORE_EXPORT QDebug operator<<(QDebug, const QUrl &);
 #endif
 
+QT_END_NAMESPACE
+
 QT_END_HEADER
 
 #endif // QURL_H
